from distutils.core import setup

setup(
    name="baizhanSuperMath11111",     #对外我们模块的名字
    version="1.0",#版本号
    description="测试第一个模块",  #描述
    author="Dreamer",#作者
    author_email="1835488236@qq.com",#作者邮箱
    py_modules=["baizhanSuperMath.dome1","baizhanSuperMath.dome2"]


)